Class: PaymentsApi::Transaction

Inherits:
ApiModelBase show all
Defined in:
lib/pnap_payments_api/models/transaction.rb

Overview

Transaction response model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Transaction

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/pnap_payments_api/models/transaction.rb', line 87

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PaymentsApi::Transaction` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PaymentsApi::Transaction`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'details')
    self.details = attributes[:'details']
  end

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  else
    self.amount = nil
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  else
    self.currency = nil
  end

  if attributes.key?(:'date')
    self.date = attributes[:'date']
  else
    self.date = nil
  end

  if attributes.key?(:'metadata')
    self. = attributes[:'metadata']
  else
    self. = nil
  end

  if attributes.key?(:'card_payment_method_details')
    self.card_payment_method_details = attributes[:'card_payment_method_details']
  else
    self.card_payment_method_details = nil
  end
end

Instance Attribute Details

#amountObject

The transaction amount.



29
30
31
# File 'lib/pnap_payments_api/models/transaction.rb', line 29

def amount
  @amount
end

#card_payment_method_detailsObject

Returns the value of attribute card_payment_method_details.



39
40
41
# File 'lib/pnap_payments_api/models/transaction.rb', line 39

def card_payment_method_details
  @card_payment_method_details
end

#currencyObject

The transaction currency.



32
33
34
# File 'lib/pnap_payments_api/models/transaction.rb', line 32

def currency
  @currency
end

#dateObject

Date and time when transaction was created.



35
36
37
# File 'lib/pnap_payments_api/models/transaction.rb', line 35

def date
  @date
end

#detailsObject

Details about the transaction. Contains failure reason in case of failed transactions.



26
27
28
# File 'lib/pnap_payments_api/models/transaction.rb', line 26

def details
  @details
end

#idObject

The Transaction ID.



20
21
22
# File 'lib/pnap_payments_api/models/transaction.rb', line 20

def id
  @id
end

#metadataObject

Returns the value of attribute metadata.



37
38
39
# File 'lib/pnap_payments_api/models/transaction.rb', line 37

def 
  @metadata
end

#statusObject

The Transaction status. Status may be: SUCCESS, PROCESSING, FAILED



23
24
25
# File 'lib/pnap_payments_api/models/transaction.rb', line 23

def status
  @status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



56
57
58
# File 'lib/pnap_payments_api/models/transaction.rb', line 56

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



61
62
63
# File 'lib/pnap_payments_api/models/transaction.rb', line 61

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



42
43
44
45
46
47
48
49
50
51
52
53
# File 'lib/pnap_payments_api/models/transaction.rb', line 42

def self.attribute_map
  {
    :'id' => :'id',
    :'status' => :'status',
    :'details' => :'details',
    :'amount' => :'amount',
    :'currency' => :'currency',
    :'date' => :'date',
    :'metadata' => :'metadata',
    :'card_payment_method_details' => :'cardPaymentMethodDetails'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
# File 'lib/pnap_payments_api/models/transaction.rb', line 298

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



80
81
82
83
# File 'lib/pnap_payments_api/models/transaction.rb', line 80

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/pnap_payments_api/models/transaction.rb', line 66

def self.openapi_types
  {
    :'id' => :'String',
    :'status' => :'String',
    :'details' => :'String',
    :'amount' => :'Float',
    :'currency' => :'String',
    :'date' => :'Time',
    :'metadata' => :'TransactionMetadata',
    :'card_payment_method_details' => :'CardPaymentMethodDetails'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



270
271
272
273
274
275
276
277
278
279
280
281
# File 'lib/pnap_payments_api/models/transaction.rb', line 270

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      status == o.status &&
      details == o.details &&
      amount == o.amount &&
      currency == o.currency &&
      date == o.date &&
       == o. &&
      card_payment_method_details == o.card_payment_method_details
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


285
286
287
# File 'lib/pnap_payments_api/models/transaction.rb', line 285

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



291
292
293
# File 'lib/pnap_payments_api/models/transaction.rb', line 291

def hash
  [id, status, details, amount, currency, date, , card_payment_method_details].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/pnap_payments_api/models/transaction.rb', line 150

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @amount.nil?
    invalid_properties.push('invalid value for "amount", amount cannot be nil.')
  end

  if @currency.nil?
    invalid_properties.push('invalid value for "currency", currency cannot be nil.')
  end

  if @date.nil?
    invalid_properties.push('invalid value for "date", date cannot be nil.')
  end

  if @metadata.nil?
    invalid_properties.push('invalid value for "metadata", metadata cannot be nil.')
  end

  if @card_payment_method_details.nil?
    invalid_properties.push('invalid value for "card_payment_method_details", card_payment_method_details cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'lib/pnap_payments_api/models/transaction.rb', line 320

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



186
187
188
189
190
191
192
193
194
195
196
# File 'lib/pnap_payments_api/models/transaction.rb', line 186

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @status.nil?
  return false if @amount.nil?
  return false if @currency.nil?
  return false if @date.nil?
  return false if @metadata.nil?
  return false if @card_payment_method_details.nil?
  true
end